#
# spec file for package scc-hypervisor-collector
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define shcuser scchvc
%define skip_python2 1
%global __python %{_bindir}/python3

%{?!python_module:%define python_module() python3-%{**}}
%{?!python_build:%define python_build %{expand:%py3_build}}
%{?!python_install:%define python_install %{expand:%py3_install}}

Name:           scc-hypervisor-collector
Version:        0.1.0~git0.90e575f
Release:        150300.7.3.2
Summary:        Regularly collect and upload hypervisor details to SUSE Customer Care
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/SUSE/scc-hypervisor-collector
Source0:        scc-hypervisor-collector-%{version}.tar.xz
Source1:        scc-hypervisor-collector.service
Source2:        scc-hypervisor-collector.timer
BuildRequires:  %{python_module importlib-metadata}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  virtual-host-gatherer-Libvirt
BuildRequires:  virtual-host-gatherer-VMware
Requires:       %{name}-common == %{version}
BuildArch:      noarch
%if 0%{?suse_version} < 1530
BuildRequires:  %{python_module setuptools}
%endif

%description
This package contains the systemd timer and service scripts that will
run the scc-hypervisor-collector on a regular basis.

%package common
Summary:        Tool to collect and upload hypervisor details to SUSE Customer Care
Group:          System/Management
Requires:       %{python_module importlib-metadata}
Requires:       %{python_module PyYAML}
Requires:       %{python_module requests}
Requires:       openssh-clients
Requires:       virtual-host-gatherer-Libvirt
Requires:       virtual-host-gatherer-VMware

%description common
This package contains a script to gather information about virtual
machines running on various hypervisors & VM management solutions.

%prep
%setup -q -n scc-hypervisor-collector-%{version}

%build
%python_build

%install
%python_install

mkdir -p %{buildroot}%{_mandir}/man1
install -m 0644 doc/man/%{name}.1 %{buildroot}%{_mandir}/man1/
mkdir -p %{buildroot}%{_mandir}/man5
install -m 0644 doc/man/%{name}.5 %{buildroot}%{_mandir}/man5/
mkdir -p %{buildroot}%{_mandir}/man8
install -m 0644 doc/man/%{name}.service.8 %{buildroot}%{_mandir}/man8/

# install service related components
install -p -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
install -p -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.timer
mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

%fdupes %{buildroot}%{python_sitelib}

%check
export PYTHONPATH=%{buildroot}%{python_sitelib}

# ensure example config permissions are correct
chmod -R g-rwx,o-rwx examples
%{buildroot}%{_bindir}/%{name} -h
%{buildroot}%{_bindir}/%{name} --check --config examples/all_in_one/shc_cfg.yaml
%{buildroot}%{_bindir}/%{name} --check --config-dir examples/creds_and_backends
%{buildroot}%{_bindir}/%{name} --check --config_dir examples/multiple_files

# run tests
export NO_NETWORK_ACCESS=true
pytest -vv

%pre
getent group %{shcuser} >/dev/null || groupadd -r %{shcuser}
getent passwd %{shcuser} >/dev/null || useradd -r -g %{shcuser} \
  -d %{_localstatedir}/lib/%{shcuser} \
  -s /sbin/nologin \
  -c "user for %{name}" %{shcuser}
if [ ! -d %{_localstatedir}/lib/%{shcuser} ]; then
  mkdir -m 700 %{_localstatedir}/lib/%{shcuser}
  chown %{shcuser}:%{shcuser} %{_localstatedir}/lib/%{shcuser}
fi

%service_add_pre %{name}.service
%service_add_pre %{name}.timer

%post
%service_add_post %{name}.service
%service_add_post %{name}.timer

%preun
%service_del_preun %{name}.timer
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.timer
%service_del_postun %{name}.service

%files
%{_sbindir}/rc%{name}
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}.timer

%{_mandir}/man8/*

%files common
%{_bindir}/%{name}

%license LICENSE
%doc README.md
%{_mandir}/man1/*
%{_mandir}/man5/*

%dir %{python_sitelib}/scc_hypervisor_collector
%{python_sitelib}/scc_hypervisor_collector/*.py*
%dir %{python_sitelib}/scc_hypervisor_collector/api
%{python_sitelib}/scc_hypervisor_collector/api/*.py*
%dir %{python_sitelib}/scc_hypervisor_collector/cli
%{python_sitelib}/scc_hypervisor_collector/cli/*.py*

%dir %{python_sitelib}/scc_hypervisor_collector/__pycache__
%{python_sitelib}/scc_hypervisor_collector/__pycache__/*.py*
%dir %{python_sitelib}/scc_hypervisor_collector/api/__pycache__
%{python_sitelib}/scc_hypervisor_collector/api/__pycache__/*.py*
%dir %{python_sitelib}/scc_hypervisor_collector/cli/__pycache__
%{python_sitelib}/scc_hypervisor_collector/cli/__pycache__/*.py*
%{python_sitelib}/scc_hypervisor_collector-*.egg-info

%changelog
* Wed Jun 14 2023 fmccarthy@suse.com
- Remove source service related settings in preparation for submission
  to SUSE:SLE-15-SP3:Update as part of ECO PED-3623.
* Thu Jan 19 2023 fmccarthy@suse.com
- Update to version 0.1.0~git0.90e575f:
  * Bump version: 0.0.5 → 0.1.0
  * Update scc-hypervisor-collector.1 man page
  * Adhoc_Testing.md enhancements
  * Apply typo fixes from code review
  * Add doc/Adhoc_Testing.md with explanation of testing tools.
  * Add gen_large_datasets and bulk_create utilities
  * Add support for Python 3.11, fix Python 3.6 testing
* Mon Oct 31 2022 fmccarthy@suse.com
- Update to version 0.0.5~git22.98337a3:
  * Fix main package's version specification for common package
* Fri Oct 28 2022 fmccarthy@suse.com
- Update to version 0.0.5~git20.6a5bfb7:
  * Remove github/obs integration
  * Documentation tweaks and improved examples
  * Add maintenance workflow documentation
* Thu Oct 27 2022 fmccarthy@suse.com
- Update to version 0.0.5~git14.c41f188:
  * Package and container build service integration tweaks
* Wed Oct 26 2022 fmccarthy@suse.com
- Update to version 0.0.5~git12.13e47d1:
  * Disable bumpversion tagging
  * Packaging tweaks
  * Miscellaneous cleanup items.
  * Add timeout parameter to requests
  * Enhance container build Dockerfile with tag settings
  * Bump version: 0.0.4 → 0.0.5
  * Bump version: 0.0.3 → 0.0.4
* Mon Oct 17 2022 fmccarthy@suse.com
- Update to version 0.0.3~git14.a401b0d:
  * obs workflow to trigger service run
* Tue Oct  4 2022 fmccarthy@suse.com
- Update to version 0.0.3~git9.4c895d9:
  * Handle 429 upon upload to SCC
  * Updated comments to clarify what a test is doing.
  * Implement file save/upload mechanisms
  * Make SCC server url configurable
* Thu Sep 22 2022 fmccarthy@suse.com
- Update to version 0.0.3~git2.f1b683b:
  * Promote optionalVmData fields to siblings of vm_name in properties
* Thu Sep 15 2022 fmccarthy@suse.com
- Update to version 0.0.3~git0.f735e1a:
  * Bump version: 0.0.2 → 0.0.3
* Wed Sep 14 2022 fmccarthy@suse.com
- Update to version 0.0.2~git53.f5f6944:
  * Skip CLI credentials check if NO_NETWORK_ACCESS env var set
* Wed Sep 14 2022 fmccarthy@suse.com
- Update to version 0.0.2~git51.6d16fb0:
  * Update the structure of the payload and route
  * Initial implementation of SCCUploader
  * Update entrypoint.bash
  * Update doc/Security.md
  * Add additional documentation
* Wed Jun 22 2022 fmccarthy@suse.com
- Update to version 0.0.2~git43.6075836:
  * Incorporate further review feedback
  * Add additional tests
  * Include log file access permissions details in man pages.
  * Include generated man pages in the repo
  * man pages for the scc-hypervisor-collector
* Wed Jun 15 2022 fmccarthy@suse.com
- Update to version 0.0.2~git36.e3b9d2e:
  * Apply suggestions from code review to simplify boolean property implementations
  * Continue processing remaining backends upon failure on any
* Fri Jun 10 2022 fmccarthy@suse.com
- Update to version 0.0.2~git33.576042a:
  * entrypoint.bash installs certs from ~scchvc/certs
* Thu Jun  9 2022 fmccarthy@suse.com
- Update to version 0.0.2~git31.2ef8f72:
  * Apply suggestions from code review
  * systemd settings tweaks and add OBS container build support.
  * handle exceptions gracefully
* Mon Jun  6 2022 fmccarthy@suse.com
- Update to version 0.0.2~git26.7596079:
  * Tweak packaging
* Mon Jun  6 2022 fmccarthy@suse.com
- Update to version 0.0.2~git24.aff90f3:
  * Update log message format
  * Tests for checking logs for sensitive information
* Wed Jun  1 2022 fmccarthy@suse.com
- Update _service definition to extract systemd service and timer
  files from sources.
* Wed Jun  1 2022 fmccarthy@suse.com
- Update to version 0.0.2~git20.65480b0:
  * Add systemd integration support to package build
* Wed Jun  1 2022 fmccarthy@suse.com
- Update to add systemd integration and split into multiple packages
  * Add initial versions of systemd service and timer files
  * Split command and Python module out into -common package
  * Base package depends on it and just contains systemd support
* Tue May 31 2022 fmccarthy@suse.com
- Update to version 0.0.2~git18.e27f17d:
  * Restructure logging
* Tue May 24 2022 fmccarthy@suse.com
- Update to version 0.0.2~git16.8688657:
  * Run tests during package build
* Tue May 24 2022 fmccarthy@suse.com
- Update to version 0.0.2~git14.433ce99:
  * Ensure CI testing runs all checks
  * check-manifest needs to ignore spec file.
* Fri May 20 2022 fmccarthy@suse.com
- Update to version 0.0.2~git10.8028ff8:
  * Ensure examples config permissions are correct for spec check
* Fri May 20 2022 fmccarthy@suse.com
- Update to version 0.0.2~git8.3ad17ba:
  * Validate file permissions
  * Add spec file to support package building
* Fri May 20 2022 fmccarthy@suse.com
- Update to version 0.0.2~git4.db792b3:
  * virtual-host-gatherer integration cleanup
  * Add helper scripts for the tox dev venv
* Thu May 19 2022 fmccarthy@suse.com
- Update to version 0.0.2~git0.83b7a43:
  * Bump version: 0.0.1 → 0.0.2
  * Fix lingering .dev_venv references
  * update handling of the parsed backends key
  * support check mode to report all possible config errors
  * Add support for merging backend definitions.
  * Enable pytest coverage failures being propagated
  * Ensure unittests run with an isolated home directory
  * Implement unittests
  * Flesh out skeleton framework.
  * implement github workflow to run tox
* Wed May 18 2022 fmccarthy@suse.com
- remove support for building for SLE 12 SP5
* Wed May 18 2022 fmccarthy@suse.com
- Cleanup the spec file using spec-cleaner
* Tue May 17 2022 fmccarthy@suse.com
- Fix typo (VHG VMWare support plugin package is called VMware)
* Tue May 10 2022 fmccarthy@suse.com
- Apply local patches for proposed virtual-host-gatherer integration
  changes:
  * scc-hypervisor-collector-PR17.patch - remove integration hacks
* Tue May 10 2022 fmccarthy@suse.com
- Initial package build hacking
  * main branch @e8fccc62845caf0ed0a7e296adb62f87fbd45951
